# remirepo spec file for php-pecl-awscrt
#
# Copyright (c) 2021-2023 Remi Collet
# License: CC-BY-SA-4.0
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#

# TODO unsuitable for Fedora with tons of bundled lib

%{?scl:%scl_package  php-pecl-awscrt}

# For PHP < 5.6 and EPEL-9
%{!?__phpize:      %global __phpize       %{_bindir}/phpize}
%{!?__ztsphpize:   %global __ztsphpize    %{_bindir}/zts-phpize}
%{!?__phpconfig:   %global __phpconfig    %{_bindir}/php-config}
%{!?__ztsphpconfig:%global __ztsphpconfig %{_bindir}/zts-php-config}

# not wanted for now
%global with_zts     0
%global pecl_name    awscrt
%global ini_name     40-%{pecl_name}.ini
%global sources      %{pecl_name}-%{version}
%global _configure   ../%{sources}/configure

Summary:        AWS Common Runtime PHP bindings
Name:           %{?scl_prefix}php-pecl-%{pecl_name}
Version:        1.2.2
Release:        1%{?dist}%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}
# extension is Apache-2.0
# see LICENSE* for rust libraries
License:        Apache-2.0 AND MIT AND BSD-3-Clause
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{sources}.tgz

%if 0%{?rhel} == 7 && 0%{?dtsversion} == 0
BuildRequires:  devtoolset-6-toolchain
%global dtsversion 6
%global dtsenable source /opt/rh/devtoolset-6/enable
%global dtsprefix devtoolset-6-
%endif
BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-devel >= 5.5
BuildRequires:  %{?scl_prefix}php-cli
BuildRequires:  %{?scl_prefix}php-pear
BuildRequires:  openssl-devel
%if 0%{?rhel} == 7
BuildRequires:  cmake3
%else
BuildRequires:  cmake
%endif

# List from config.m4
Provides:       bundled(libaws-crt-ffi)
Provides:       bundled(libaws-c-auth)
Provides:       bundled(libaws-c-http)
Provides:       bundled(libaws-c-io)
Provides:       bundled(libaws-c-cal)
Provides:       bundled(libaws-c-compression)
Provides:       bundled(libaws-checksums)
Provides:       bundled(libaws-c-common)

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}

Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}


%description
AWS Common Runtime provides a set of low level tools as network protocols and
authentication used by the AWSSDK for PHP to provide high level API to access
AWS services.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c

# Don't install/register tests
sed -e 's/role="test"/role="src"/' \
    -e 's/role="doc"/role="src"/' \
    %{!?_licensedir:-e '/LICENSE/s/role="src"/role="doc"/' } \
    -e '/"CODE_OF_CONDUCT.md"/s/role="src"/role="doc"/'\
    -e '/"CONTRIBUTING.md"/s/role="src"/role="doc"/'\
    -e '/"README.md"/s/role="src"/role="doc"/'\
    -i package.xml

pushd %{sources}
# Parallel build
sed -e '/(CMAKE_BUILD)/s/$/ --verbose %{?_smp_mflags}/' -i Makefile.frag

# Workaround for https://github.com/awslabs/aws-crt-php/issues/35
sed -e 's/-Werror//' \
    -i crt/aws-crt-ffi/crt/*/CMakeLists.txt
popd

mkdir NTS
%if %{with_zts}
mkdir ZTS
%endif

# Create configuration file
cat << 'EOF' | tee %{ini_name}
; Enable '%{summary}' extension module
extension=%{pecl_name}.so

: Configuration
;awscrt.log_level = ''
EOF


%build
%{?dtsenable}
%if 0%{?scl:1}
# make invokes php command
source /opt/%{scl_vendor}/%{scl}/enable
%endif

export PHP_RPATH=no

cd %{sources}
%{__phpize}

cd ../NTS
%configure \
    --with-awscrt \
    --with-libdir=%{_lib} \
    --with-php-config=%{__phpconfig}
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%configure \
    --with-awscrt \
    --with-libdir=%{_lib} \
    --with-php-config=%{__ztsphpconfig}
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

make -C NTS \
     install INSTALL_ROOT=%{buildroot}

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
make -C ZTS \
     install INSTALL_ROOT=%{buildroot}

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 %{sources}/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{pecl_name} >/dev/null || :
fi
%endif


%check
# Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}/%{php_extdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

%if %{with_zts}
# Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}/%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}
%endif


%files
%{?_licensedir:%license %{sources}/LICENSE}
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Thu Jul 27 2023 Remi Collet <remi@remirepo.net> - 1.2.2-1
- update to 1.2.2
- buld out of sources tree

* Wed Mar 29 2023 Remi Collet <remi@remirepo.net> - 1.2.1-1
- update to 1.2.1
- drop patch merged upstream

* Fri Mar 17 2023 Remi Collet <remi@remirepo.net> - 1.2.0-1
- update to 1.2.0 (stable)
- fix https://github.com/awslabs/aws-crt-php/issues/95 PHP 5.x compatibility
  using patch from https://github.com/awslabs/aws-crt-php/pull/96

* Thu Mar 16 2023 Remi Collet <remi@remirepo.net> - 1.1.0-1
- update to 1.1.0 (devel)

* Wed Mar 15 2023 Remi Collet <remi@remirepo.net> - 1.0.11-1
- update to 1.0.11 (devel)

* Tue Mar 14 2023 Remi Collet <remi@remirepo.net> - 1.0.10-1
- update to 1.0.10 (devel)
- open https://github.com/awslabs/aws-crt-php/issues/93 version stability

* Tue Feb 15 2022 Remi Collet <remi@remirepo.net> - 1.0.9-1
- update to 1.0.9 (devel, no change)

* Sat Sep 11 2021 Remi Collet <remi@remirepo.net> - 1.0.8-1
- update to 1.0.8 (stable, no change)

* Fri Sep  3 2021 Remi Collet <remi@remirepo.net> - 1.0.7-1
- update to 1.0.7 (stable)

* Wed Sep 01 2021 Remi Collet <remi@remirepo.net> - 1.0.4-2
- rebuild for 8.1.0RC1

* Fri Jul  9 2021 Remi Collet <remi@remirepo.net> - 1.0.4-1
- update to 1.0.4

* Tue Jun 29 2021 Remi Collet <remi@remirepo.net> - 1.0.1-1
- update to 1.0.1
- open https://github.com/awslabs/aws-crt-php/issues/37 incomplete archive
- open https://github.com/awslabs/aws-crt-php/issues/38 missing tag

* Wed Jun 23 2021 Remi Collet <remi@remirepo.net> - 1.0.0-1
- initial package, version 1.0.0 (devel)
- open https://github.com/awslabs/aws-crt-php/issues/34 broken archive
- open https://github.com/awslabs/aws-crt-php/issues/35 broken build
